## Christopher Potts and Florian Schwarz
## For "Affective 'this'" (Linguistic Issues in Language Technology)
## Submitted 2009-06-19
## Revised 2009-12-11

source("exclamativity.R")
source("solidarity.R")

######################################################################
######################################################################
## Height and width for postscript output files. Assumes a 2x2 panel.
## Use <Width, Height/2> for 1x2 panels and <Width/2, Height/2> for 1x1
## panels.
Height=8
Width=8

######################################################################
######################################################################
## Frequency and log-odds for 'superb'

Corpus = read.csv("unigrams.english.csv")

superb = subset(Corpus, Word=="superb")

postscript("plots/superb.ps",  width=Width, height=Height/2, horizontal=FALSE)
par(mfrow=c(1,2))

plot(superb$Rating, superb$TokenCount/superb$RatingWideCount,
     main="Frequency distribution",
     ylab="Frequency",
     xlab="Rating",
     cex.axis=1.3, cex.main=1.3, cex.lab=1.3, cex.sub=1.3, pch=19)

plot(superb$Rating, log(superb$TokenCount / (superb$RatingWideCount - superb$TokenCount)),
     main="Log-odds distribution",
     ylab="Log-odds",
     xlab="Rating",
     cex.axis=1.3, cex.main=1.3, cex.lab=1.3, cex.sub=1.3, pch=19)

dev.off()

######################################################################
######################################################################
## EXCLAMATIVITY PLOTS

Corpus = read.csv("unigrams.english.csv")

postscript("plots/exclamatives.ps", width=Width, height=Height, horizontal=FALSE)
par(mfrow=c(2,2),cex.axis=1.55, cex.main=1.55, cex.lab=1.55, cex.sub=1.55)
exclamativityPlot(Corpus, "absolutely", Title="absolutely")
exclamativityPlot(Corpus, "damn", Title="damn")
exclamativityPlot(Corpus, "wow", Title="wow")
exclamativityPlot(Corpus, "!", Title="Exclamation mark")
dev.off()

## Nonemotional.
postscript("plots/nonexclamatives.ps",width=Width, height=Height, horizontal=FALSE)
par(mfrow=c(2,2),cex.axis=1.55, cex.main=1.55, cex.lab=1.55, cex.sub=1.55)
exclamativityPlot(Corpus, "the", Title="the")
exclamativityPlot(Corpus, "but", Title="but")
exclamativityPlot(Corpus, "quite", Title="quite")
exclamativityPlot(Corpus, "somewhat", Title="somewhat")
dev.off()

Corpus = read.csv("dems.csv")

## This.
postscript("plots/exclamativity-this.ps", width=Width, height=Height/2,, horizontal=FALSE)
par(mfrow=c(1,2),cex.axis=1.3, cex.main=1.3, cex.lab=1.3, cex.sub=1.3)
exclamativityPlot(Corpus, "thisDET", Title="Determiner `this'")
exclamativityPlot(Corpus, "thisPRO", Title="Pronominal `this'")
dev.off()

## That.
postscript("plots/exclamativity-that.ps", width=Width, height=Height/2, horizontal=FALSE)
par(mfrow=c(1,2),cex.axis=1.3, cex.main=1.3, cex.lab=1.3, cex.sub=1.3)
exclamativityPlot(Corpus, "thatDET", Title="Determiner `that'")
exclamativityPlot(Corpus, "thatPRO", Title="Pronominal `that'")
dev.off()

## Dies-.
par(cex.axis=1.3, cex.main=1.3, cex.lab=1.3, cex.sub=1.3)
postscript("plots/exclamativity-dies.ps", width=Width/2, height=Height/2, horizontal=FALSE)
exclamativityPlot(Corpus, "dies", Title="German `dies-'")
dev.off()

######################################################################
######################################################################
# COMPARE COEFFICIENTS

coefSE = function(Phrase, Corpus){
  PhraseFrame = subset(Corpus, Word==Phrase)
  glm = glm(formula = cbind(PhraseFrame$TokenCount, PhraseFrame$RatingWideCount - PhraseFrame$TokenCount) ~ poly(Rating,2,raw=TRUE), family="binomial", data=PhraseFrame)
  coef = glm$coef[3]
  se = summary.glm(glm)$coefficients[6]
  return(c(coef,se))
}

Corpus = read.csv("unigrams.english.csv")

absolutely.coef.se = coefSE("absolutely", Corpus)
damn.coef.se = coefSE("damn", Corpus)
wow.coef.se = coefSE("wow", Corpus)
bang.coef.se = coefSE("!", Corpus)
the.coef.se = coefSE("the", Corpus)
but.coef.se = coefSE("but", Corpus)
quite.coef.se = coefSE("quite", Corpus)
somewhat.coef.se = coefSE("somewhat", Corpus)

Corpus = read.csv("dems.csv")

thisPRO.coef.se = coefSE("thisPRO", Corpus)
thisNP.coef.se = coefSE("thisDET", Corpus)


coefs = c(absolutely.coef.se[1], damn.coef.se[1], wow.coef.se[1], bang.coef.se[1], thisPRO.coef.se[1], thisNP.coef.se[1], the.coef.se[1], but.coef.se[1], quite.coef.se[1], somewhat.coef.se[1])
ses   = c(absolutely.coef.se[2], damn.coef.se[2], wow.coef.se[2], bang.coef.se[2], thisPRO.coef.se[2], thisNP.coef.se[2], the.coef.se[2], but.coef.se[2], quite.coef.se[2], somewhat.coef.se[2])

library(gplots)

postscript("plots/exclamativity-coefs.ps", width=12, height=7, horizontal=FALSE)
par(cex.axis=1.3, cex.main=1.3, cex.lab=1.3, cex.sub=1.3)
plotCI(x=coefs, uiw=ses, gap=0, xaxt='n',
       ylab="Quadratic coefficient",
       xlab="")

axis(1, at=seq(1:length(coefs)),
     labels=c("absolutely", "damn", "wow", "Exc. mark", "Pro. this", "Det. this", "the", "but", "quite", "somewhat"),
     las=3)

lines(c(0,length(coefs)+1), c(0,0))

dev.off()

######################################################################
######################################################################
## SOLIDARITY PLOTS

dets = read.csv("byproduct.english.dems.csv")

postscript("plots/solidarity-this.ps",width=Width, height=Height/2, horizontal=FALSE)
par(mfrow=c(1,2),cex.axis=1.3, cex.main=1.3, cex.lab=1.3, cex.sub=1.3, pch=19)
solidarityPlot(dets, dets$thisDET, "Determiner `this'")
solidarityPlot(dets, dets$thisPRO, "Pronominal `this'")
dev.off()

postscript("plots/solidarity-that.ps",width=Width, height=Height/2, horizontal=FALSE)
par(mfrow=c(1,2),cex.axis=1.3, cex.main=1.3, cex.lab=1.3, cex.sub=1.3, pch=19)
solidarityPlot(dets, dets$thatDET, "Determiner `that'")
solidarityPlot(dets, dets$thatPRO, "Pronominal `that'")
dev.off()

par(cex.axis=1.3, cex.main=1.3, cex.lab=1.3, cex.sub=1.3, pch=19)
postscript("plots/solidarity-dies.ps",width=Width/2, height=Height/2, horizontal=FALSE)
dies = read.csv("byproduct.german.dies.csv")
solidarityPlot(dies, dies$dies, "German `dies-'")
dev.off()

######################################################################
######################################################################
## EXISTENTIALS PLOT

## The values in the arrays this and an are the frequencies of
## evaluative language in existentials headed by 'this' and 'an',
## respectively, for 100 random samples of 20 sentences each from each
## of the two collections of exisential types. Section 2.2 provides
## more details.

this = c(0.0532544378698225, 0.0590062111801242, 0.0597014925373134, 0.0606060606060606, 0.0608974358974359, 0.0622950819672131, 0.0625, 0.062874251497006, 0.0630630630630631, 0.0640243902439024, 0.0653950953678474, 0.0660919540229885, 0.0664819944598338, 0.0666666666666667, 0.0670553935860058, 0.0672043010752688, 0.0672514619883041, 0.0672782874617737, 0.0680473372781065, 0.0686015831134565, 0.068870523415978, 0.0704607046070461, 0.072192513368984, 0.0722543352601156, 0.0728862973760933, 0.0729166666666667, 0.0735294117647059, 0.0739549839228296, 0.073972602739726, 0.0744336569579288, 0.0745341614906832, 0.0747126436781609, 0.0749279538904899, 0.0754189944134078, 0.075801749271137, 0.076056338028169, 0.0761421319796954, 0.0761904761904762, 0.0767045454545455, 0.0769230769230769, 0.077639751552795, 0.0780780780780781, 0.0783699059561129, 0.0786885245901639, 0.0789473684210526, 0.0789473684210526, 0.079136690647482, 0.0792682926829268, 0.0795454545454545, 0.0795755968169761, 0.08, 0.0801104972375691, 0.0801393728222996, 0.0803571428571429, 0.0813559322033898, 0.0816326530612245, 0.0823170731707317, 0.0828402366863905, 0.0830945558739255, 0.0837988826815642, 0.0841121495327103, 0.0842391304347826, 0.0842696629213483, 0.084375, 0.084985835694051, 0.0852272727272727, 0.0852713178294574, 0.0852941176470588, 0.0853242320819113, 0.0854700854700855, 0.0856164383561644, 0.0856353591160221, 0.0862533692722372, 0.0867208672086721, 0.0868055555555556, 0.0869565217391304, 0.0876288659793814, 0.0876623376623377, 0.0882352941176471, 0.0885416666666667, 0.0891891891891892, 0.0903614457831325, 0.0906735751295337, 0.0911458333333333, 0.0917159763313609, 0.0921052631578947, 0.0922619047619048, 0.0931989924433249, 0.0942028985507246, 0.0952380952380952, 0.0953846153846154, 0.0955631399317406, 0.0960960960960961, 0.0970350404312668, 0.100286532951289, 0.100574712643678, 0.100574712643678, 0.101736972704715, 0.105121293800539, 0.107238605898123)

an = c(0.0348837209302326, 0.046448087431694, 0.046875, 0.0469613259668508, 0.0477386934673367, 0.0515151515151515, 0.0533807829181495, 0.0549450549450549, 0.055045871559633, 0.056547619047619, 0.0565552699228792, 0.0567164179104478, 0.0569395017793594, 0.0570652173913043, 0.0572207084468665, 0.0578034682080925, 0.0580645161290323, 0.0581395348837209, 0.0582191780821918, 0.058252427184466, 0.058659217877095, 0.0590631364562118, 0.0591397849462366, 0.0594059405940594, 0.0596205962059621, 0.0605263157894737, 0.0606936416184971, 0.062111801242236, 0.0636942675159236, 0.0638888888888889, 0.0643564356435644, 0.0656716417910448, 0.0658682634730539, 0.066006600660066, 0.0660377358490566, 0.0664556962025316, 0.0664556962025316, 0.0664556962025316, 0.0666666666666667, 0.0671378091872792, 0.0675105485232067, 0.0675675675675676, 0.0684326710816777, 0.0687830687830688, 0.0688524590163934, 0.0694864048338369, 0.0695443645083933, 0.0698324022346369, 0.0701754385964912, 0.0712166172106825, 0.0712166172106825, 0.0732484076433121, 0.0734177215189873, 0.073482428115016, 0.0741573033707865, 0.0743494423791822, 0.0748299319727891, 0.0752351097178683, 0.0753968253968254, 0.0765661252900232, 0.0766666666666667, 0.0771704180064309, 0.0775623268698061, 0.0776515151515152, 0.0783783783783784, 0.0785340314136126, 0.0788643533123028, 0.0790273556231003, 0.0790697674418605, 0.0794392523364486, 0.0796703296703297, 0.0798722044728434, 0.08, 0.08, 0.0803108808290155, 0.0803108808290155, 0.0812182741116751, 0.0816326530612245, 0.0823863636363636, 0.0825396825396825, 0.0831024930747922, 0.0835820895522388, 0.0863787375415282, 0.0875420875420875, 0.0875420875420875, 0.0886426592797784, 0.089086859688196, 0.0892857142857143, 0.0895522388059701, 0.0897009966777409, 0.0899470899470899, 0.0907079646017699, 0.092436974789916, 0.093167701863354, 0.094017094017094, 0.0942249240121581, 0.0952380952380952, 0.0979020979020979, 0.0995575221238938, 0.104938271604938)

postscript("plots/existentials.ps",  width=Width, height=Height, horizontal=FALSE)
boxplot(this, an,
        names=c("'this' pivot", "'a(n)' pivot"),
        notch=T,
        cex.axis=1.3, cex.main=1.3, cex.lab=1.3, cex.sub=1.3,
        ylab="Frequency of evaluative predicates (log-scale)",
        xlab="Existential-'there' pivots",
        log='y')  

dev.off()

######################################################################
